package zephyr.android.gnews.app;

import zephyr.services.gnews.*;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.Button;
import android.widget.ListView;
import android.widget.TextView;

public class NewsListActivity extends AbstractAsyncActivity {
	private PMAndroidNewsList pmNewsList;
	
	@Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }
	
	@Override
	public void onStart() {
		super.onStart();		
		// when this activity starts, initiate an asynchronous HTTP GET request
		if(this.pmNewsList==null)
			new NewsSearchTask().execute(1);
		else
			refreshResults(this.pmNewsList);
	}
	
	//***************************************
    // Private methods
    //*************************************** 
	private void showError(String errorDetails) {
		AlertDialog.Builder builder = new AlertDialog.Builder(this);
		builder.setMessage(errorDetails)
		       .setCancelable(false)		       
		       .setNegativeButton("No", new DialogInterface.OnClickListener() {
		           public void onClick(DialogInterface dialog, int id) {
		                dialog.cancel();
		                new NewsSearchTask().execute(1);
		           }
		       });
		AlertDialog alert = builder.create();
		alert.show();
	}	
	
	//***************************************
    // Private methods
    //*************************************** 
	private void refreshResults(PMAndroidNewsList response) {
		if (response == null) {
			return;
		}
		
		if(this.pmNewsList.getPageNews().isEmpty()){
			setContentView(R.layout.news_search_results_empty);
			return;
		}
			
		setContentView(R.layout.news_list_results);
		
		Button btnPrev=(Button)findViewById(R.id.btnPrev);
		Button btnNext=(Button)findViewById(R.id.btnNext);
		TextView txtPage=(TextView)findViewById(R.id.txtPage);
		txtPage.setText("page "+this.pmNewsList.getCurrentPageNo()+" / "+this.pmNewsList.getNoOfPages());
		ListView lstNewsList=(ListView)findViewById(R.id.lstNewsList);
		NewsAdapter adapter=new NewsAdapter(getApplicationContext(), this.pmNewsList);
		lstNewsList.setAdapter(adapter);
		lstNewsList.setOnItemClickListener(new OnItemClickListener(){
			@Override
			public void onItemClick(AdapterView<?> parent, View v, int position,
					long arg3) {
				// TODO Auto-generated method stub
				NewsItem news=pmNewsList.getNewsAt(position);
				startActivity(new Intent(Intent.ACTION_VIEW, Uri.parse(news.getUnescapedUrl())));
			}
			
		});
		btnPrev.setOnClickListener(new OnClickListener(){
			@Override
			public void onClick(View arg0) {
				// TODO Auto-generated method stub
				if(pmNewsList.getCurrentPageNo()!=1)
					new NewsSearchTask().execute(pmNewsList.getCurrentPageNo()-1);
			}			
		});
		btnNext.setOnClickListener(new OnClickListener(){
			@Override
			public void onClick(View arg0) {
				// TODO Auto-generated method stub
				if(pmNewsList.getNoOfPages()>pmNewsList.getCurrentPageNo())
					new NewsSearchTask().execute(pmNewsList.getCurrentPageNo()+1);
			}
		});
	}	
	
	//***************************************
    // Private classes
    //***************************************
	private class NewsSearchTask extends AsyncTask<Integer, Void, PMAndroidNewsList> {
		
		@Override
		protected void onPreExecute() {
			// before the network request begins, show a progress indicator
			showLoadingProgressDialog();
		}

		@Override
		protected PMAndroidNewsList doInBackground(Integer... pageNo) {
			try {
				NewsService svc=new NewsService();
				ServiceResponse res=svc.searchNews(4, pageNo[0]);
				PMAndroidNewsList response=new PMAndroidNewsList(res);
				
				return response;
			} catch (Exception e) {
				Log.e(TAG, e.getMessage(), e);
			}

			return null;
		}
		
		@Override
		protected void onPostExecute(PMAndroidNewsList response) {
			// hide the progress indicator when the network request is complete
			dismissProgressDialog();
			pmNewsList=response;
			
			// return the Google results
			if(!(response.getServiceResponse().getResponseStatus()).equals("OK"))
				showError(response.getServiceResponse().getErrorDetails());
			else
				refreshResults(response);
		}
	}
}