package zephyr.services.gnews;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;


import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.http.ContentCodingType;
import org.springframework.http.ResponseEntity;
import org.springframework.http.converter.HttpMessageConverter;
import org.springframework.http.converter.json.GsonHttpMessageConverter;
import org.springframework.web.client.RestTemplate;

import android.util.Log;

public class NewsService {
	private String url="https://ajax.googleapis.com/ajax/services/search/news?v=1.0";	
	
	public NewsService(){
		if(Preferences.mode.equals("general"))
			this.url=String.format(this.url+"&geo=%s", Preferences.geo);
		else if(Preferences.mode.equals("geo-query"))
			this.url=String.format(this.url+"&geo=%s&q=%s", Preferences.geo, java.net.URLEncoder.encode(Preferences.query));
		else if(Preferences.mode.equals("query"))
			this.url=String.format(this.url+"&q=%s", java.net.URLEncoder.encode(Preferences.query));		
	}
	
	public ServiceResponse searchNews(int itemsPerPage, int pageNo){
		String url=String.format(this.url+"&rsz=%d&start=%d", itemsPerPage, (pageNo-1)*itemsPerPage);		
		
		RestTemplate restTemplate = new RestTemplate();	
		HttpHeaders reqHeaders=new HttpHeaders();
		reqHeaders.setAcceptEncoding(Collections.singletonList(ContentCodingType.GZIP));
		
		HttpEntity<?> requestEntity=new HttpEntity<Object>(reqHeaders);
		
		
		// Set a custom GsonHttpMessageConverter that supports the text/javascript media type
		GsonHttpMessageConverter messageConverter = new GsonHttpMessageConverter();
		messageConverter.setSupportedMediaTypes(Collections.singletonList(new MediaType("text", "javascript")));
		List<HttpMessageConverter<?>> messageConverters = new ArrayList<HttpMessageConverter<?>>();
		messageConverters.add(messageConverter);
		restTemplate.setMessageConverters(messageConverters);

		// Perform the HTTP GET request to the Google search API
		ResponseEntity<GoogleNewsResponse> responseEntity = restTemplate.exchange(url, HttpMethod.GET, requestEntity, GoogleNewsResponse.class);
		
		ServiceResponse response;
		
		GoogleNewsResponse googleResponse=responseEntity.getBody();
		if(!googleResponse.getResponseStatus().equals("200")){
			//Log.e(TAG, newsResponse.getResponseDetails(), e);
			response=new ServiceResponse(null, 0, 4, 0);
			response.setErrorDetails(googleResponse.getResponseDetails());
			response.setResponseStatus(googleResponse.getResponseStatus());
			
			return response;
		}
		
		
		List<NewsItem> newsResults=googleResponse.getResponseData().getResults();
		long estimatedResultCount=newsResults.size()==0?0:(googleResponse.getCursor()).getEstimatedResultCount();						
		response=new ServiceResponse(newsResults, estimatedResultCount, itemsPerPage, pageNo);
		
		
		return response;
	}
}